#include "odbc-3.x.hh"

#line 1 "test-5.uesql.cc"
/*
*  Name:      test-1.uesql.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for UESQL
*  Date:      $Date: 2000/09/12 11:21:03 $
*  Revision:  $Revision: 1.6 $
*
*  Copyright (C) 2000  Dedalo Ingenieros, S.L.
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdlib>
#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>


//
//  L O C A L   V A R I A B L E S
//

static uesql::TSqlstateDescriptor   _tSqlstateDescriptor;
  

//
//  L O C A L   F U N C T I O N S
//

/**
*  Construct error message from SQL status.
*  @return SQL status message.
*/
static mpcl::xstring _GetErrorMessage (void)
{

  using mpcl::xstring;

  return ( xstring (_tSqlstateDescriptor.getClass())    +
           ": "                                         +
           xstring (_tSqlstateDescriptor.getSubclass()) +
           " (" + uesql::SQLMESSAGE + ")"               );

}  // _GetErrorMessage()


/**
*  Main.
*
*  Parameters:
*
*    {-o, --dbms-server-name}=DBMS-SERVER-NAME
*    {-u, --dbms-user-name}=DBMS-USER-NAME
*    {-p, --dbms-user-password}=PASSWORD
*/
int main (int argc, const char* argv[])
{

  using mpcl::Format;
  using mpcl::TConfigProcessor;
  using mpcl::xstring;
  using std::cerr;
  using std::endl;
  using uesql::ComposeQuotedSchemaLocation;
  using uesql::ComposeSchemaLocation;
  using uesql::ComposeUserLogin;
  using uesql::Quote;
  using uesql::TSqlString;
  
  TEST_INIT ("Test for SCHEMA related statements");
  TEST_START_WATCH;

  TSqlString         yVar0;
  TSqlString         yVar1;
  TSqlString         yVar2;
  TSqlString         yCursorName;
  TSqlString         yDbmsUserLogin;
  TSqlString         yDbmsSchemaLocation;
  TSqlString         yDbmsServerName;
  TConfigProcessor   tConfigProcessor (argc, argv);
  const char*        pcDbmsServerName = getenv ("DBMS_SERVER_NAME");
  const char*        pcDbmsUserName   = getenv ("DBMS_USER_NAME");

  try
  {
    //
    //  Checks environment variables.
    //
    if ( !pcDbmsServerName )
    {
      pcDbmsServerName = "localhost";
    }
    if ( !pcDbmsUserName )
    {
      pcDbmsUserName = getenv ("USER");
      if ( !pcDbmsUserName )
      {
        pcDbmsUserName = "";
      }
    }
    
    //
    //  Define string constants names for options.
    //
    tConfigProcessor.addOption ("dbms-server-name",   "o", pcDbmsServerName);
    tConfigProcessor.addOption ("dbms-user-name",     "u", pcDbmsUserName);
    tConfigProcessor.addOption ("dbms-user-password", "p", pcDbmsUserName);
    tConfigProcessor.processOptions();
    
    yDbmsServerName     = tConfigProcessor ["dbms-server-name"].value();
    yDbmsUserLogin      = tConfigProcessor ["dbms-user-name"].value();
    yDbmsSchemaLocation = ComposeSchemaLocation
                          (
                            yDbmsServerName                             ,
                            tConfigProcessor ["dbms-user-name"].value()
                          );

    //
    //  If there is a password then appends it to the user-login string.
    //
    if ( !tConfigProcessor ["dbms-user-password"].value().empty() )
    {
      yDbmsUserLogin = ComposeUserLogin
                       (
                         yDbmsUserLogin                                  ,
                         tConfigProcessor ["dbms-user-password"].value() 
                       );
    }
  }
  catch (const mpcl::TBaseException& rktEXCEPTION)
  {
    cerr << rktEXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }

  TEST_WRITE_INFO ("DBMS-SCHEMA-LOCATION = %s", yDbmsSchemaLocation.c_str());
  TEST_WRITE_INFO ("DBMS-USER-LOGIN      = %s", yDbmsUserLogin.c_str());
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.also (cerr);
  }
  if ( !yDbmsServerName.empty() && !yDbmsUserLogin.empty() )
  {
#line 159 "test-5.uesql.cc"
{
//
//  ODBC 3.x instructions.
//
#line 163 "test-5.uesql.cc"

#line 169 "test-5.uesql.cc"
{
mpcl::xstring              hySqlSchemaLocation;
mpcl::xstring              hyDatabaseName;
mpcl::xstring              hyConnectionName;
mpcl::xstring              hyUserLogin;
mpcl::xstring::size_type   zSolidusPos;

uesql::htOdbc3xManager.clearQueues();
uesql::htOdbc3xManager.pushOnInputQueue (Quote (yDbmsServerName));
uesql::htOdbc3xManager.pushOnInputQueue (Quote (yDbmsUserLogin));

//
//  '$z' has been omitted.
//
hySqlSchemaLocation = uesql::htOdbc3xManager.instantiate ("$z");
hyConnectionName    = "DEFAULT";
hyUserLogin         = uesql::htOdbc3xManager.instantiate ("$z");
hySqlSchemaLocation.suppress ('\'');
zSolidusPos = hySqlSchemaLocation.find ('/');
if ( zSolidusPos == mpcl::xstring::npos )
{
  hyDatabaseName = hySqlSchemaLocation;
}
else
{
  hyDatabaseName = hySqlSchemaLocation.substr (0, zSolidusPos);
}
if ( uesql::htOdbc3xManager.isConnected (hyConnectionName) )
{
  uesql::htOdbc3xManager.disconnect (hyConnectionName);
}
if ( uesql::htOdbc3xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  goto error;
}
else
{
  uesql::htOdbc3xManager.connect ( hyConnectionName ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
  {
    goto error;
  }
  else
  {
    uesql::htOdbc3xManager.setCurrentConnection (hyConnectionName);
  }
}
}
#line 185 "test-5.uesql.cc"
{
//
//  Non terminal <schema element list> is not used.
//
uesql::odbc_3_x::TResultTriple   htResultTriple;

uesql::htOdbc3xManager.clearQueues();

htResultTriple = uesql::htOdbc3xManager.execute ("CREATE SCHEMA TEST_1_SCHEMA  CREATE TABLE TABLE_1 (CODE CHARACTER (3) NOT NULL, WORKER_COUNT INTEGER) CREATE TABLE TABLE_2 (WORK_CODE CHARACTER (3) NOT NULL, NAME CHARACTER (40) NOT NULL, HOURS DECIMAL (5));");
uesql::htOdbc3xManager.diagnose (htResultTriple);
uesql::htOdbc3xManager.clearResult (htResultTriple);
if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 192 "test-5.uesql.cc"
{
mpcl::xstring              hySqlSchemaLocation;
mpcl::xstring              hyDatabaseName;
mpcl::xstring              hyConnectionName;
mpcl::xstring              hyUserLogin;
mpcl::xstring::size_type   zSolidusPos;

uesql::htOdbc3xManager.clearQueues();
uesql::htOdbc3xManager.pushOnInputQueue (ComposeQuotedSchemaLocation (yDbmsServerName, "TEST_1_SCHEMA"));
uesql::htOdbc3xManager.pushOnInputQueue (Quote (yDbmsUserLogin));

hySqlSchemaLocation = uesql::htOdbc3xManager.instantiate ("$z");
hyConnectionName    = uesql::htOdbc3xManager.instantiate ("_'myconnection'");
hyUserLogin         = uesql::htOdbc3xManager.instantiate ("$z");
hySqlSchemaLocation.suppress ('\'');
hyConnectionName.suppress ('\'');
zSolidusPos = hySqlSchemaLocation.find ('/');
if ( zSolidusPos == mpcl::xstring::npos )
{
  hyDatabaseName = hySqlSchemaLocation;
}
else
{
  hyDatabaseName = hySqlSchemaLocation.substr (0, zSolidusPos);
}
if ( uesql::htOdbc3xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  goto error;
}
else
{
  uesql::htOdbc3xManager.connect ( hyConnectionName ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
  {
    goto error;
  }
  else
  {
    uesql::htOdbc3xManager.setCurrentConnection (hyConnectionName);
  }
}
}
#line 197 "test-5.uesql.cc"
{
uesql::odbc_3_x::TResultTriple   htResultTriple;

uesql::htOdbc3xManager.clearQueues();

htResultTriple = uesql::htOdbc3xManager.execute ("DROP TABLE TABLE_1 CASCADE;");
uesql::htOdbc3xManager.diagnose (htResultTriple);
uesql::htOdbc3xManager.clearResult (htResultTriple);
if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 198 "test-5.uesql.cc"
{
uesql::htOdbc3xManager.clearQueues();

if ( uesql::htOdbc3xManager.existsDefaultConnection() )
{
  uesql::SQLCODE    = 0;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "00000";
  uesql::htOdbc3xManager.disconnectCurrent();
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08003";
  goto error;
}
}
#line 199 "test-5.uesql.cc"
{
mpcl::xstring   hyConnectionName;

uesql::htOdbc3xManager.clearQueues();

hyConnectionName = uesql::htOdbc3xManager.instantiate ("DEFAULT");
hyConnectionName.suppress ('\'');
uesql::htOdbc3xManager.setCurrentConnection (hyConnectionName);
if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 204 "test-5.uesql.cc"
{
uesql::odbc_3_x::TResultTriple   htResultTriple;

uesql::htOdbc3xManager.clearQueues();

htResultTriple = uesql::htOdbc3xManager.execute ("DROP SCHEMA TEST_1_SCHEMA CASCADE;");
uesql::htOdbc3xManager.diagnose (htResultTriple);
uesql::htOdbc3xManager.clearResult (htResultTriple);
if ( uesql::htOdbc3xManager.isSqlerrorCondition() )
{
  goto error;
}
}
}  // not ODBC 3.x
#line 205 "test-5.uesql.cc"

  }
  goto end;

error:
  cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
  cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
  cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
  TEST_FAIL_WITH_CODE (uesql::SQLCODE);

end:
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.erase (cerr);
  }
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
