#include "postgresql-libpq-6.2.x.hh"

#line 1 "test-1.uesql.cc"
/*
*  Name:      test-1.uesql.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for UESQL
*  Date:      $Date: 2000/09/12 11:21:03 $
*  Revision:  $Revision: 1.41 $
*
*  Copyright (C) 1996-1999  Rafael Jesus Alcantara Perez <rafa@dedalo-ing.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdlib>
#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>


//
//  L O C A L   V A R I A B L E S
//

static uesql::TSqlstateDescriptor   _tSqlstateDescriptor;
  

//
//  L O C A L   F U N C T I O N S
//

/**
*  Construct error message from SQL status.
*  @return SQL status message.
*/
static mpcl::xstring _GetErrorMessage (void)
{

  using mpcl::xstring;

  return ( xstring (_tSqlstateDescriptor.getClass())    +
           ": "                                         +
           xstring (_tSqlstateDescriptor.getSubclass()) +
           " (" + uesql::SQLMESSAGE + ")"               );

}  // _GetErrorMessage()


static int _TestCursors (void)
{

  using mpcl::xstring;
  using std::cerr;
  using std::endl;
  using uesql::TSqlString;

  TSqlString   yVar0;
  TSqlString   yVar1;
  TSqlString   yVar2;
  bool         gEmpty       = true;
  TSqlString   yAttribName  = "WORK_CODE";
  size_t       zRecordCount = 0;

  TEST_INIT ("test for cursors");

#line 79 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 80 "test-1.uesql.cc"

#line 81 "test-1.uesql.cc"

#line 85 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE MYCURSOR CURSOR FOR SELECT NAME, HOURS FROM WORKERS WHERE ( NAME = 'nobody' );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 86 "test-1.uesql.cc"

}  // not PostgreSQL LIBPQ 6.2.x
#line 87 "test-1.uesql.cc"

  while ( true )
  {
#line 91 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 92 "test-1.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar0);
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar1);

ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN MYCURSOR;");
uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto loop_end;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto error;
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "FETCHED (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 93 "test-1.uesql.cc"

    gEmpty = false;
  }

loop_end:
#line 99 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 100 "test-1.uesql.cc"
uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("CLOSE MYCURSOR;");
uesql::htPostgresql62xManager.executeClean ("END;");

}  // not PostgreSQL LIBPQ 6.2.x
#line 101 "test-1.uesql.cc"

  if ( gEmpty )
  {
    TEST_PASS;
  }
  else
  {
    TEST_FAIL;
  }

#line 112 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 116 "test-1.uesql.cc"

#line 117 "test-1.uesql.cc"

#line 122 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (yAttribName);

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE MYCURSOR CURSOR FOR SELECT $z, NAME, HOURS FROM WORKERS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 123 "test-1.uesql.cc"

}  // not PostgreSQL LIBPQ 6.2.x
#line 124 "test-1.uesql.cc"

    
  if ( hptTestTargetFile )
  {
    fprintf (hptTestTargetFile, "%s\n", "WORK_CODE NAME                                     HOURS");
    fprintf (hptTestTargetFile, "%s\n", "========= ======================================== =====");
  }
  while ( true )
  {
#line 134 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 135 "test-1.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar0);
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar1);
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar2);

ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN MYCURSOR;");
uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto loop_end_2;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto error;
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "FETCHED (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 136 "test-1.uesql.cc"

    if ( hptTestTargetFile )
    {
      fprintf (hptTestTargetFile, "%9s %40s %5s\n", yVar0.c_str(), yVar1.c_str(), yVar2.c_str());
    }
    ++zRecordCount;
  }

loop_end_2:
#line 146 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 150 "test-1.uesql.cc"
uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("CLOSE MYCURSOR;");
uesql::htPostgresql62xManager.executeClean ("END;");

}  // not PostgreSQL LIBPQ 6.2.x
#line 151 "test-1.uesql.cc"

  goto end;

error:
  cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
  cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
  cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
  TEST_FAIL_WITH_CODE (uesql::SQLCODE);  

end:
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;
  
}  // _TestCursors()


static int _TestSqlTypes (void)
{

  TEST_INIT ("test for SQL types");

  using std::cerr;
  using std::endl;
  using std::size_t;
  using uesql::TSqlDate;
  using uesql::TSqlInteger;
  using uesql::TSqlReal;
  using uesql::TSqlString;

  TSqlDate      tSqlDate;
  TSqlInteger   tSqlInteger;
  TSqlReal      tSqlReal;
  TSqlString    ySqlString;
  size_t        zRecordCount = 0;

  TEST_NUMBERS (1,     TSqlInteger ("1"));
  TEST_NUMBERS (0,     TSqlInteger ("0"));
  TEST_NUMBERS (10000, TSqlInteger ("10000"));
  TEST_NUMBERS (10001, TSqlInteger (10001));
  tSqlInteger.getBuffer (12);
  tSqlInteger.getBuffer (12);
  tSqlInteger.getBuffer (12);
  tSqlInteger.set ("75000");
  TEST_NUMBERS (75000, tSqlInteger);
#line 196 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 197 "test-1.uesql.cc"

#line 198 "test-1.uesql.cc"

#line 205 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("CREATE TABLE TABLE_1 (CODE CHAR (3) NOT NULL, BIRTH_DATE DATE, SALARY INT4, PERCENTAGE FLOAT8);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 206 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO TABLE_1 VALUES ('000', '1999-12-31', 12000, 25.75);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 207 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO TABLE_1 VALUES ('001', '1970-01-01', 75000, 30);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 208 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO TABLE_1 VALUES ('002', '2000-01-01', 11500, 99.99);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 212 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlDate (2000, 12, 31));
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlInteger (7500));
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlReal (33.33));

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO TABLE_1 VALUES ('003', $z, $z, $z);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 216 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlDate (2001,  1,  1));
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlInteger (6500));
uesql::htPostgresql62xManager.pushOnInputQueue (TSqlReal (0.0));

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO TABLE_1 VALUES ('004', $z, $z, $z);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 218 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE MYCURSOR CURSOR FOR SELECT CODE, BIRTH_DATE, SALARY, PERCENTAGE FROM TABLE_1;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 219 "test-1.uesql.cc"

}  // not PostgreSQL LIBPQ 6.2.x
#line 220 "test-1.uesql.cc"


  //
  //  Writes the example table.
  //
  if ( hptTestTargetFile )
  {
    fprintf (hptTestTargetFile, "%s\n", "CODE BIRTH_DATE   SALARY PERCENTAGE");
    fprintf (hptTestTargetFile, "%s\n", "==== ============ ====== ==========");
  }
  while ( true )
  {
#line 233 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 234 "test-1.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&ySqlString);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tSqlDate);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tSqlInteger);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tSqlReal);

ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN MYCURSOR;");
uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto loop_end;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto error;
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "FETCHED (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 235 "test-1.uesql.cc"

    if ( hptTestTargetFile )
    {
      fprintf ( hptTestTargetFile          ,
                "%3s  %12s %6ld %10.03f\n" ,
                ySqlString.c_str()         ,
                tSqlDate.get().c_str()     ,
                (long int) tSqlInteger     ,
                (double) tSqlReal          );
    }
    ++zRecordCount;
  }

loop_end:
#line 250 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 251 "test-1.uesql.cc"
uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("CLOSE MYCURSOR;");
uesql::htPostgresql62xManager.executeClean ("END;");

#line 252 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DROP TABLE TABLE_1;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 253 "test-1.uesql.cc"

  if ( zRecordCount == 5 )
  {
    TEST_PASS;
  }
  else
  {
    TEST_FAIL;
  }
  goto end;

error:
  cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
  cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
  cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
  TEST_FAIL_WITH_CODE (uesql::SQLCODE);  

end:  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // _TestSqlTypes()


/**
*  Main.
*
*  Parameters:
*
*    {-o, --dbms-server-name}=DBMS-SERVER-NAME
*    {-u, --dbms-user-name}=DBMS-USER-NAME
*    {-p, --dbms-user-password}=PASSWORD
*/
int main (int argc, const char* argv[])
{

  using mpcl::Format;
  using mpcl::TConfigProcessor;
  using mpcl::xstring;
  using std::cerr;
  using std::endl;
  using uesql::ComposeQuotedSchemaLocation;
  using uesql::ComposeSchemaLocation;
  using uesql::ComposeUserLogin;
  using uesql::Quote;
  using uesql::TSqlString;
  
  TEST_INIT ("test-1");
  TEST_START_WATCH;

  TSqlString         yVar0;
  TSqlString         yVar1;
  TSqlString         yVar2;
  TSqlString         yCursorName;
  TSqlString         yDbmsUserLogin;
  TSqlString         yDbmsSchemaLocation;
  TSqlString         yDbmsServerName;
  TConfigProcessor   tConfigProcessor (argc, argv);
  TSqlString         yCodeValue ("002");
  const char*        pcDbmsServerName = getenv ("DBMS_SERVER_NAME");
  const char*        pcDbmsUserName   = getenv ("DBMS_USER_NAME");
  TSqlString*        pyDbmsUserLogin  = &yDbmsUserLogin;

  try
  {
    //
    //  Checks environment variables.
    //
    if ( !pcDbmsServerName )
    {
      pcDbmsServerName = "localhost";
    }
    if ( !pcDbmsUserName )
    {
      pcDbmsUserName = getenv ("USER");
      if ( !pcDbmsUserName )
      {
        pcDbmsUserName = "";
      }
    }
    
    //
    //  Define string constants names for options.
    //
    tConfigProcessor.addOption ("dbms-server-name",   "o", pcDbmsServerName);
    tConfigProcessor.addOption ("dbms-user-name",     "u", pcDbmsUserName);
    tConfigProcessor.addOption ("dbms-user-password", "p", pcDbmsUserName);
    tConfigProcessor.processOptions();
    
    yDbmsServerName     = tConfigProcessor ["dbms-server-name"].value();
    yDbmsUserLogin      = tConfigProcessor ["dbms-user-name"].value();
    yDbmsSchemaLocation = ComposeSchemaLocation
                          (
                            yDbmsServerName                             ,
                            tConfigProcessor ["dbms-user-name"].value() 
                          );

    //
    //  If there is a password then appends it to the user-login string.
    //
    if ( !tConfigProcessor ["dbms-user-password"].value().empty() )
    {
      yDbmsUserLogin = ComposeUserLogin
                       (
                         yDbmsUserLogin                                  ,
                         tConfigProcessor ["dbms-user-password"].value() 
                       );
    }
  }
  catch (const mpcl::TBaseException& rktEXCEPTION)
  {
    cerr << rktEXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }

  TEST_WRITE_INFO ("DBMS-SCHEMA-LOCATION = %s", yDbmsSchemaLocation.c_str());
  TEST_WRITE_INFO ("DBMS-USER-LOGIN      = %s", yDbmsUserLogin.c_str());
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.also (cerr);
  }
  if ( !yDbmsServerName.empty() && !yDbmsUserLogin.empty() )
  {
#line 377 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 381 "test-1.uesql.cc"

#line 382 "test-1.uesql.cc"

#line 388 "test-1.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyUserLogin;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsSchemaLocation));
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsUserLogin));

hySqlServerDescriptor = uesql::htPostgresql62xManager.instantiate ("$z");
hyConnectionName      = "DEFAULT";
hyUserLogin           = uesql::htPostgresql62xManager.instantiate ("$z");
hySqlServerDescriptor.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == mpcl::xstring::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  uesql::htPostgresql62xManager.disconnect (hyConnectionName);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  goto error;
}
else
{
  if ( hyDatabaseName.empty() )
  {
    //
    //  If there is no PostgreSQL database then connect to 'template1'
    //  (that should always exists).
    //
    hyDatabaseName = "template1";
  }
  uesql::htPostgresql62xManager.connect ( hyConnectionName ,
                                     hySqlServerName  ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
  {
    goto error;
  }
  else
  {
    uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
  }
}
}
#line 397 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("CREATE TABLE JOBS (CODE CHAR (3) NOT NULL, WORKER_COUNT INT4);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 404 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("CREATE TABLE WORKERS (WORK_CODE CHAR (3) NOT NULL, NAME CHAR (40) NOT NULL, HOURS DECIMAL (5));");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 409 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("ALTER TABLE WORKERS ADD COLUMN STATE CHAR (40);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 410 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("ALTER TABLE WORKERS ADD COLUMN PHONE_NUMBER INT4;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 415 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yCodeValue));

ptPgresult = uesql::htPostgresql62xManager.execute ("DELETE FROM JOBS WHERE ( CODE = $z );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 416 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DELETE FROM JOBS WHERE ( CODE = '001' );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 417 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DELETE FROM WORKERS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 422 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO JOBS VALUES ('001', 100);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 423 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO JOBS VALUES ('002', 250);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 424 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS VALUES ('001', 'myname', 40, 'Andalucia', 5550000);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 425 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS VALUES ('001', 'yourname', 35, 'Extremadura', 5550001);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 426 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS VALUES ('001', 'hisname', 25, 'Catalunya', 5550002);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 427 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS VALUES ('002', 'john', 35, 'New England', 5550003);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 428 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS VALUES ('002', 'james', 35, 'Washington', 5550004);");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 429 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS WHERE ( NAME = 'myname' );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 430 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 435 "test-1.uesql.cc"

#line 442 "test-1.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar1);

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE AUX_CURSOR CURSOR FOR SELECT HOURS FROM WORKERS, JOBS WHERE ( WORK_CODE = CODE );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( !uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH ALL IN AUX_CURSOR;");
  uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
}
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
  goto not_found;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
  goto cardinality_check;
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "SELECTED (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 443 "test-1.uesql.cc"

    TEST_FAIL;

cardinality_check:
    TEST_STRINGS (uesql::SQLSTATE.c_str(), "21000");
    yCursorName = "MYCURSOR";
#line 450 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 454 "test-1.uesql.cc"

#line 459 "test-1.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar2);

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE AUX_CURSOR CURSOR FOR SELECT COUNT (*) FROM WORKERS WHERE ( NAME = 'myname' );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( !uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH ALL IN AUX_CURSOR;");
  uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
}
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
  goto not_found;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
  goto error;
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "SELECTED (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.executeClean ("END;");
}
}
#line 466 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("UPDATE WORKERS SET PHONE_NUMBER = WORKERS.PHONE_NUMBER WHERE ( ( WORKERS.NAME = 'myname' ) AND ( WORKERS.NAME = NAME ) );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 467 "test-1.uesql.cc"

    TEST_FUNCTION (_TestCursors());
    TEST_FUNCTION (_TestSqlTypes());
#line 471 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 475 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("BEGIN;");
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE MYCURSOR CURSOR FOR SELECT CODE FROM JOBS WHERE ( CODE = '001' );");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 476 "test-1.uesql.cc"

#line 477 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (yCursorName);
uesql::htPostgresql62xManager.pushOnOutputQueue (&yVar0);

ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN $z;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto not_found;
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  goto error;
}
else
{
  {
int   hI = 0;

#ifdef _UESQL_DEBUG__
mpcl::log << mpcl::header << "USING (";
#endif  // not _UESQL_DEBUG__
uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
#ifdef _UESQL_DEBUG__
mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
#endif  // not _UESQL_DEBUG__
++hI;
#ifdef _UESQL_DEBUG__
mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
}
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
#line 478 "test-1.uesql.cc"
uesql::htPostgresql62xManager.clearQueues();

uesql::htPostgresql62xManager.executeClean ("CLOSE MYCURSOR;");
uesql::htPostgresql62xManager.executeClean ("END;");

}  // not PostgreSQL LIBPQ 6.2.x
#line 479 "test-1.uesql.cc"

    TEST_STRINGS (uesql::SQLSTATE.c_str(), "00000");
    TEST_STRINGS (yVar2.c_str(),           "4");
    TEST_STRINGS (yVar0.c_str(),           "001");
#line 484 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 488 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("REVOKE ALL ON JOBS FROM PUBLIC;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 489 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'RESTRICT' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("REVOKE ALL ON WORKERS FROM PUBLIC;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 494 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("GRANT SELECT ON JOBS TO PUBLIC;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 495 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("GRANT SELECT ON WORKERS TO PUBLIC;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 496 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("GRANT DELETE ON WORKERS TO PUBLIC;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 501 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("CREATE VIEW VIEW1 AS SELECT * FROM JOBS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 506 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DROP VIEW VIEW1;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 511 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DROP TABLE JOBS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
#line 516 "test-1.uesql.cc"
{
uesql::htPostgresql62xManager.clearQueues();

if ( uesql::htPostgresql62xManager.existsDefaultConnection() )
{
  uesql::SQLCODE    = 0;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "00000";
  uesql::htPostgresql62xManager.disconnectCurrent();
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08003";
  goto error;
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 517 "test-1.uesql.cc"


#line 520 "test-1.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 526 "test-1.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyUserLogin;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsSchemaLocation));
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (*pyDbmsUserLogin));

hySqlServerDescriptor = uesql::htPostgresql62xManager.instantiate ("$z");
hyConnectionName      = uesql::htPostgresql62xManager.instantiate ("_'myconnection'");
hyUserLogin           = uesql::htPostgresql62xManager.instantiate ("$z");
hySqlServerDescriptor.suppress ('\'');
hyConnectionName.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == mpcl::xstring::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  goto error;
}
else
{
  if ( hyDatabaseName.empty() )
  {
    //
    //  If there is no PostgreSQL database then connect to 'template1'
    //  (that should always exists).
    //
    hyDatabaseName = "template1";
  }
  uesql::htPostgresql62xManager.connect ( hyConnectionName ,
                                     hySqlServerName  ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
  {
    goto error;
  }
  else
  {
    uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
  }
}
}
#line 531 "test-1.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DROP TABLE WORKERS;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  goto error;
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 532 "test-1.uesql.cc"

    goto end;

  error:
    cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
    cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
    cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
    TEST_FAIL_WITH_CODE (uesql::SQLCODE);
    goto end;

  not_found:
    cerr << "Search failed\n";
    TEST_FAIL_WITH_CODE (2);
    goto end;
  }

end:
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.erase (cerr);
  }
  TEST_STOP_WATCH;
  TEST_DISPLAY_WATCH ("UESQL benchmark");
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
